@@ -5,7 +5,7 @@
 @(#)Purpose:         ESQL/C Library Function Prototypes
 @(#)Author:          J Leffler
 @(#)Copyright:       (C) JLSS 1992-93,1995-97
-@(#)Product:         $Product: DBD::Informix Version 0.97.PC1 (2000-01-18) $
+@(#)Product:         DBD::Informix Version 0.97002 (2000-01-24)
 */
 
 /*TABSTOP=4*/
@@ -15,7 +15,7 @@
 
 #ifdef MAIN_PROGRAM
 #ifndef lint
-static const char esqllib_h[] = "@(#)$Id: esqllib.h,v 1.10 1997/06/02 16:24:26 johnl Exp $";
+static const char esqllib_h[] = "@(#)$Id: esqllib.h version /main/10 1997-06-02 16:24:26 $";
 #endif	/* lint */
 #endif	/* MAIN_PROGRAM */
 
