@@ -5,7 +5,7 @@
 @(#)Purpose:         ESQL/C Utility Functions for DBD::Informix
 @(#)Author:          J Leffler
 @(#)Copyright:       (C) Jonathan Leffler 1997-98
-@(#)Product:         $Product: DBD::Informix Version 0.97.PC1 (2000-01-18) $
+@(#)Product:         DBD::Informix Version 0.97002 (2000-01-24)
 */
 
 /*TABSTOP=4*/
@@ -15,7 +15,7 @@
 
 #ifdef MAIN_PROGRAM
 #ifndef lint
-static const char ixblob_h[] = "@(#)$Id: ixblob.h,v 50.3 1998/04/09 21:48:10 jleffler Exp $";
+static const char ixblob_h[] = "@(#)$Id: ixblob.h version /main/4 1998-04-09 21:48:10 $";
 #endif	/* lint */
 #endif	/* MAIN_PROGRAM */
 
